django-historylinks
===================

**django-historylinks** provides automatic SEO-friendly HTTP 301 redirects if the
URL of a registered model changes.


Features
--------

* Tracks old URLs associated with a model and provides 301 redirects to the new URL.
* Simple one-line registration for each model.


Documentation
-------------

Please read the [Getting Started][] guide for more information.

[Getting Started]: https://github.com/etianen/django-historylinks/wiki
    "Getting started with django-historylinks"
    
Download instructions, bug reporting and links to full documentation can be
found at the [main project website][].

[main project website]: http://github.com/etianen/django-historylinks
    "django-historylinks on GitHub"

You can keep up to date with the latest announcements by joining the
[django-historylinks discussion group][].

[django-historylinks discussion group]: http://groups.google.com/group/django-historylinks
    "django-historylinks Google Group"

    
More information
----------------

The django-historylinks project was developed by Dave Hall. You can get the code
from the [django-historylinks project site][].

[django-historylinks project site]: http://github.com/etianen/django-historylinks
    "django-historylinks on GitHub"
    
Dave Hall is a freelance web developer, based in Cambridge, UK. You can usually
find him on the Internet in a number of different places:

*   [Website](http://www.etianen.com/ "Dave Hall's homepage")
*   [Twitter](http://twitter.com/etianen "Dave Hall on Twitter")
*   [Google Profile](http://www.google.com/profiles/david.etianen "Dave Hall's Google profile")